ThemeBuilder

Trait ThemeBuilder 

pub trait ThemeBuilder {
    type Context;

    // Required method
    fn build(context: &Self::Context) -> Self;
}
A trait for building a theme from a given context.

This trait is typically derived using tui-theme-builder::ThemeBuilder from the tui-theme-builder-derive crate.

Required Associated Types

type Context

The type of context used to build the theme.

Required Methods

fn build(context: &Self::Context) -> Self

Builds and returns an instance of the implementing type using the provided context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors